@@ -6,11 +6,9 @@ use strict;
 use warnings;
 use routines;
 
-use Sub::Util ();
-
 use parent 'Data::Object::Name';
 
-our $VERSION = '2.06'; # VERSION
+our $VERSION = '2.07'; # VERSION
 
 # METHODS
 
@@ -163,6 +161,27 @@ method cop($func, @args) {
   return sub { $next->(@args ? (@args, @_) : @_) };
 }
 
+method data() {
+  no strict 'refs';
+
+  my $class = $self->package;
+
+  local $.;
+
+  my $handle = \*{"${class}::DATA"};
+
+  return '' if !fileno $handle;
+
+  seek $handle, 0, 0;
+
+  my $data = join '', <$handle>;
+
+  $data =~ s/^.*\n__DATA__\r?\n/\n/s;
+  $data =~ s/\n__END__\r?\n.*$/\n/s;
+
+  return $data;
+}
+
 method destroy() {
   require Symbol;
 
@@ -234,7 +253,7 @@ method init() {
 
   if ($self->routine('import')) {
 
-    return $self->package;
+    return $class;
   }
 
   $class = $self->locate ? $self->load : $self->package;
@@ -248,6 +267,7 @@ method init() {
     my $import = sub { $class };
 
     $self->inject('import', $import);
+    $self->load;
 
     return $class;
   }
@@ -264,14 +284,20 @@ method included() {
 }
 
 method inject($name, $coderef) {
+  my $class = $self->package;
+
+  local $@;
   no strict 'refs';
   no warnings 'redefine';
 
-  my $class = $self->package;
-
-  return *{"${class}::${name}"} = Sub::Util::set_subname(
-    "${class}::${name}", $coderef || sub{$class}
-  );
+  if (state $subutil = eval "require Sub::Util") {
+    return *{"${class}::${name}"} = Sub::Util::set_subname(
+      "${class}::${name}", $coderef || sub{$class}
+    );
+  }
+  else {
+    return *{"${class}::${name}"} = $coderef || sub{$class};
+  }
 }
 
 method load() {
@@ -397,6 +423,12 @@ method rebase(@args) {
   return $class->new($self->base)->prepend($path);
 }
 
+method require($target) {
+  $target = "'$target'" if -f $target;
+
+  return $self->eval("require $target");
+}
+
 method root() {
 
   return $self->parse->[0];
@@ -478,6 +510,31 @@ method siblings() {
   ];
 }
 
+method use($target, @params) {
+  my $version;
+
+  my $class = $self->package;
+
+  ($target, $version) = @$target if ref $target eq 'ARRAY';
+
+  $self->require($target);
+
+  require Scalar::Util;
+
+  my @statement = (
+    'no strict "subs";',
+    (
+      Scalar::Util::looks_like_number($version)
+        ? "${target}->VERSION($version);" : ()
+    ),
+    'sub{ my ($target, @params) = @_; $target->import(@params)}'
+  );
+
+  $self->eval(join("\n", @statement))->($target, $class, @params);
+
+  return $self;
+}
+
 method used() {
   my $class = $self->package;
   my $path = $self->path;
@@ -962,6 +1019,29 @@ and if successful returns a closure.
 
 =cut
 
+=head2 data
+
+  data() : Str
+
+The data method attempts to read and return any content stored in the C<DATA>
+section of the package namespace.
+
+=over 4
+
+=item data example #1
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('foo');
+
+  $space->data; # ''
+
+=back
+
+=cut
+
 =head2 destroy
 
   destroy() : Object
@@ -1600,6 +1680,27 @@ specified to the base of the current object's namespace.
 
 =cut
 
+=head2 require
+
+  require(Str $target) : Any
+
+The require method executes a C<require> statement within the package namespace
+specified.
+
+=over 4
+
+=item require example #1
+
+  # given: synopsis
+
+  $space->require('Moo');
+
+  # 1
+
+=back
+
+=cut
+
 =head2 root
 
   root() : Str
@@ -1798,6 +1899,63 @@ deep).
 
 =cut
 
+=head2 use
+
+  use(Str | Tuple[Str, Str] $target, Any @params) : Object
+
+The use method executes a C<use> statement within the package namespace
+specified.
+
+=over 4
+
+=item use example #1
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('foo/goo');
+
+  $space->use('Moo');
+
+  # $self
+
+=back
+
+=over 4
+
+=item use example #2
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('foo/hoo');
+
+  $space->use('Moo', 'has');
+
+  # $self
+
+=back
+
+=over 4
+
+=item use example #3
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('foo/ioo');
+
+  $space->use(['Moo', 9.99], 'has');
+
+  # $self
+
+=back
+
+=cut
+
 =head2 used
 
   used() : Str
